# CHANGELOG

<!-- version list -->

## v1.2.0 (2026-03-21)

### Features

- Supports aggregations=None to skip, adds permutation and SHAP as alternate feature importance
  functions
  ([`9966397`](https://github.com/kennaruk/slimtsf/commit/996639741018248643379d69757bcc145bfe8439))


## v1.1.0 (2026-03-14)

### Features

- Add pycatch22, antropy, and basic statistical feature functions
  ([`9fed0cb`](https://github.com/kennaruk/slimtsf/commit/9fed0cb631e86fdbc709eaefed743f903b79bf9c))


## v1.0.3 (2026-03-14)

### Bug Fixes

- **bootstrap**: Fix bootstrap logic
  ([`b649770`](https://github.com/kennaruk/slimtsf/commit/b6497708711278d8d53f4385560b3f2598bd1403))


## v1.0.2 (2026-03-09)

### Bug Fixes

- Ci/cd twine publish
  ([`0c05fac`](https://github.com/kennaruk/slimtsf/commit/0c05fac3f08061d7be98d3e7d6f9a37ef733061a))


## v1.0.0 (2026-03-09)

- Initial Release

## v1.0.1 (2026-03-09)

### Bug Fixes

- **CI/CD**: Correct env pypi key
  ([`fdbd0be`](https://github.com/kennaruk/slimtsf/commit/fdbd0be9c6987c320373867368e71b8f6e792eb2))


## v1.0.0 (2026-03-09)

- Initial Release
